.. _vehicle_module:

:mod:`bimmer_connected.vehicle`
===============================

The :mod:`bimmer_connected.vehicle` module contains all data & parsers for a vehicle.

:mod:`bimmer_connected.vehicle.vehicle`
---------------------------------------
 
.. automodule:: bimmer_connected.vehicle.vehicle
    :members:
    :undoc-members:


:mod:`bimmer_connected.vehicle.remote_services`
-----------------------------------------------
 
.. automodule:: bimmer_connected.vehicle.remote_services
    :members:
    :undoc-members:


:mod:`bimmer_connected.vehicle.charging_profile`
------------------------------------------------
 
.. automodule:: bimmer_connected.vehicle.charging_profile
    :members:
    :undoc-members:


:mod:`bimmer_connected.vehicle.doors_windows`
---------------------------------------------
 
.. automodule:: bimmer_connected.vehicle.doors_windows
    :members:
    :undoc-members:


:mod:`bimmer_connected.vehicle.fuel_and_battery`
------------------------------------------------
 
.. automodule:: bimmer_connected.vehicle.fuel_and_battery
    :members:
    :undoc-members:


:mod:`bimmer_connected.vehicle.location`
------------------------------------------------
 
.. automodule:: bimmer_connected.vehicle.location
    :members:
    :undoc-members:


:mod:`bimmer_connected.vehicle.models`
--------------------------------------------------------
 
.. automodule:: bimmer_connected.vehicle.models
    :members:
    :undoc-members:


:mod:`bimmer_connected.vehicle.reports`
--------------------------------------------------------
 
.. automodule:: bimmer_connected.vehicle.reports
    :members:
    :undoc-members:
